@@ -78,10 +78,13 @@ def stringify_raw_cmd(cmd: RawCmd, java_temp_dir: str = None) -> str:
 
 def json_to_cmd(json) -> RawCmd:
     json = {
-        "cwd": None,
-        "jar": None,
-        "args": None,
-    } | json
+        **{
+            "cwd": None,
+            "jar": None,
+            "args": None,
+        },
+        **json,
+    }
     cmd = RawCmd()
     cmd.cwd = json["cwd"]
     cmd.jar = json["jar"]
